.. _install-git:

=============
 Install git
=============

Overview
========

================ =============
Debian / Ubuntu  ``sudo apt-get install git-core``
Fedora           ``sudo yum install git-core``
Windows          Download and install msysGit_
OS X             Use the git-osx-installer_
================ =============

In detail
=========

See the git page for the most recent information.

Have a look at the github install help pages available from `github help`_.

There are good instructions here: `Installing Git`_.

.. include:: links.inc
